@@ -21,6 +21,7 @@ from .joy import *
 from .jpopsuki import *
 from .ku6 import *
 from .letv import *
+from .magisto import *
 from .miomio import *
 from .mixcloud import *
 from .netease import *
@@ -36,6 +37,7 @@ from .tumblr import *
 from .vid48 import *
 from .vimeo import *
 from .vine import *
+from .vk import *
 from .w56 import *
 from .xiami import *
 from .yinyuetai import *
